import type { BarcodeScannerPlugin, BarcodeScannerPluginOptions } from '../types';
/**
 * Custom hook to use an instance of the {@link BarcodeScannerPlugin}.
 *
 * @param options - The plugin options {@link BarcodeScannerPluginOptions}.
 *
 * @returns {BarcodeScannerPlugin} A memoized plugin instance that will be
 * destroyed once the component using `useBarcodeScanner()` unmounts.
 *
 * @example
 * ```ts
 * const barcodePlugin = useBarcodeScanner({ formats: ['QR_CODE'] });
 * const frameProcessor = useFrameProcessor((frame) => {
 *   'worklet';
 *   const barcodes = barcodePlugin.barcodeScanner(frame);
 *   console.log(barcodes);
 * }, [barcodePlugin]);
 * ```
 */
export declare const useBarcodeScanner: (options?: BarcodeScannerPluginOptions) => BarcodeScannerPlugin;
//# sourceMappingURL=useBarcodeScanner.d.ts.map