import type { ImageLabelerPlugin, ImageLabelerPluginOptions } from '../types';
/**
 * Custom hook to use an instance of the {@link ImageLabelerPlugin}.
 *
 * @param options - The plugin options {@link ImageLabelerPluginOptions}.
 *
 * @returns {ImageLabelerPlugin} A memoized plugin instance that will be
 * destroyed once the component using `useImageLabeler()` unmounts.
 *
 * @example
 * ```ts
 * const labelPlugin = useImageLabeler({ confidenceThreshold: 70 });
 * const frameProcessor = useFrameProcessor((frame) => {
 *   'worklet';
 *   const labels = labelPlugin.imageLabeler(frame);
 *   console.log(labels);
 * }, [labelPlugin]);
 * ```
 */
export declare const useImageLabeler: (options?: ImageLabelerPluginOptions) => ImageLabelerPlugin;
//# sourceMappingURL=useImageLabeler.d.ts.map