import type { ObjectDetectorPlugin, ObjectDetectorPluginOptions } from '../types';
/**
 * Custom hook to use an instance of the {@link ObjectDetectorPlugin}.
 *
 * @param options - The plugin options {@link ObjectDetectorPluginOptions}.
 *
 * @returns {ObjectDetectorPlugin} A memoized plugin instance that will be
 * destroyed once the component using `useObjectDetector()` unmounts.
 *
 * @example
 * ```ts
 * const objectPlugin = useObjectDetector({ enableMultipleObjects: true });
 * const frameProcessor = useFrameProcessor((frame) => {
 *   'worklet';
 *   const objects = objectPlugin.objectDetector(frame);
 *   console.log(objects);
 * }, [objectPlugin]);
 * ```
 */
export declare const useObjectDetector: (options?: ObjectDetectorPluginOptions) => ObjectDetectorPlugin;
//# sourceMappingURL=useObjectDetector.d.ts.map