import type { TextRecognizerPlugin, TextRecognizerPluginOptions } from '../types';
/**
 * Custom hook to use an instance of the {@link TextRecognizerPlugin}.
 *
 * @param options - The plugin options {@link TextRecognizerPluginOptions}.
 *
 * @returns {TextRecognizerPlugin} A memoized plugin instance that will be
 * destroyed once the component using `useTextRecognizer()` unmounts.
 *
 * @example
 * ```ts
 * const textPlugin = useTextRecognizer({ language: 'LATIN' });
 * const frameProcessor = useFrameProcessor((frame) => {
 *   'worklet';
 *   const text = textPlugin.textRecognizer(frame);
 *   console.log(text);
 * }, [textPlugin]);
 * ```
 */
export declare const useTextRecognizer: (options?: TextRecognizerPluginOptions) => TextRecognizerPlugin;
//# sourceMappingURL=useTextRecognizer.d.ts.map